marktools.BarLine
=================

.. inheritance-diagram:: abjad.tools.marktools.BarLine.BarLine.BarLine
   :private-bases:

.. autoclass:: abjad.tools.marktools.BarLine.BarLine.BarLine

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.lilypond_format

    Inherited from :py:class:`marktools.LilyPondCommandMark <abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark>`

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.bar_line_string

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.command_name

    Inherited from :py:class:`marktools.LilyPondCommandMark <abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark>`

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.format_slot

    Inherited from :py:class:`marktools.LilyPondCommandMark <abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark>`

Methods
-------

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.attach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.detach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__eq__

    Inherited from :py:class:`marktools.LilyPondCommandMark <abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`
